Module: Google::Apis::ApphubV1

Defined in:
lib/google/apis/apphub_v1.rb,
lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/service.rb,
lib/google/apis/apphub_v1/gem_version.rb,
lib/google/apis/apphub_v1/representations.rb

Overview

App Hub API

App Hub lets you build, operate, and manage applications on Google Cloud.

Defined Under Namespace

Classes: AppHubService, Application, Attributes, AuditConfig, AuditLogConfig, Binding, Boundary, CancelOperationRequest, ContactInfo, Criticality, DetachServiceProjectAttachmentRequest, DetachServiceProjectAttachmentResponse, DiscoveredService, DiscoveredWorkload, Empty, Environment, Expr, ExtendedMetadata, ExtendedMetadataSchema, FunctionalType, Identity, ListApplicationsResponse, ListDiscoveredServicesResponse, ListDiscoveredWorkloadsResponse, ListExtendedMetadataSchemasResponse, ListLocationsResponse, ListOperationsResponse, ListServiceProjectAttachmentsResponse, ListServicesResponse, ListWorkloadsResponse, Location, LookupDiscoveredServiceResponse, LookupDiscoveredWorkloadResponse, LookupServiceProjectAttachmentResponse, Operation, OperationMetadata, Policy, ReconciliationOperationMetadata, RegistrationType, Scope, Service, ServiceProjectAttachment, ServiceProperties, ServiceReference, SetIamPolicyRequest, Status, TestIamPermissionsRequest, TestIamPermissionsResponse, Workload, WorkloadProperties, WorkloadReference

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-apphub_v1 gem

"0.19.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260323"
VERSION =

Version of the App Hub API this client connects to. This is NOT the gem version.

'V1'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'