Class: Google::Apis::ApphubV1::AppHubService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ApphubV1::AppHubService
- Defined in:
- lib/google/apis/apphub_v1/service.rb
Overview
App Hub API
App Hub lets you build, operate, and manage applications on Google Cloud.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://apphub.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Creates an Application in a host project and location.
-
#create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Creates a Service in an Application.
-
#create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Creates a Workload in an Application.
-
#create_project_location_service_project_attachment(parent, service_project_attachment_object = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Attaches a service project to the host project.
-
#delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes an Application in a host project and location.
-
#delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes a Service from an Application.
-
#delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes a Workload from an Application.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Empty
Deletes a long-running operation.
-
#delete_project_location_service_project_attachment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes a service project attachment.
-
#detach_location_service_project_attachment(name, detach_service_project_attachment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::DetachServiceProjectAttachmentResponse
Detaches a service project from a host project.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Location
Gets information about a location.
-
#get_project_location_application(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Application
Gets an Application in a host project and location.
-
#get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Policy
Gets the access control policy for a resource.
-
#get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Service
Gets a Service in an Application.
-
#get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Workload
Gets a Workload in an Application.
-
#get_project_location_boundary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Boundary
Gets a Boundary.
-
#get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::DiscoveredService
Gets a Discovered Service in a host project and location.
-
#get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::DiscoveredWorkload
Gets a Discovered Workload in a host project and location.
-
#get_project_location_extended_metadata_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ExtendedMetadataSchema
Gets an Extended Metadata Schema.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ServiceProjectAttachment
Gets a service project attachment.
-
#initialize ⇒ AppHubService
constructor
A new instance of AppHubService.
-
#list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListServicesResponse
Lists Services in an Application.
-
#list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListWorkloadsResponse
Lists Workloads in an Application.
-
#list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListApplicationsResponse
Lists Applications in a host project and location.
-
#list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListDiscoveredServicesResponse
Lists Discovered Services that can be added to an Application in a host project and location.
-
#list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListDiscoveredWorkloadsResponse
Lists Discovered Workloads that can be added to an Application in a host project and location.
-
#list_project_location_extended_metadata_schemas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListExtendedMetadataSchemasResponse
Lists Extended Metadata Schemas available in a host project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_service_project_attachments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListServiceProjectAttachmentsResponse
Lists service projects attached to the host project.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::LookupDiscoveredServiceResponse
Lists a Discovered Service in a host project and location, with a given resource URI.
-
#lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::LookupDiscoveredWorkloadResponse
Lists a Discovered Workload in a host project and location, with a given resource URI.
-
#lookup_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::LookupServiceProjectAttachmentResponse
Lists a service project attachment for a given service project.
-
#patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates an Application in a host project and location.
-
#patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates a Service in an Application.
-
#patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates a Workload in an Application.
-
#set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Policy
Sets the access control policy on the specified resource.
-
#test_application_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#update_project_location_boundary(name, boundary_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates a Boundary.
Constructor Details
#initialize ⇒ AppHubService
Returns a new instance of AppHubService.
47 48 49 50 51 52 |
# File 'lib/google/apis/apphub_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-apphub_v1', client_version: Google::Apis::ApphubV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/apphub_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/apphub_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1421 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ApphubV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ApphubV1::Empty::Representation command.response_class = Google::Apis::ApphubV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Creates an Application in a host project and location.
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/google/apis/apphub_v1/service.rb', line 331 def create_project_location_application(parent, application_object = nil, application_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/applications', ) command.request_representation = Google::Apis::ApphubV1::Application::Representation command.request_object = application_object command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['parent'] = parent unless parent.nil? command.query['applicationId'] = application_id unless application_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Creates a Service in an Application.
677 678 679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/google/apis/apphub_v1/service.rb', line 677 def create_project_location_application_service(parent, service_object = nil, request_id: nil, service_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/services', ) command.request_representation = Google::Apis::ApphubV1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceId'] = service_id unless service_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Creates a Workload in an Application.
905 906 907 908 909 910 911 912 913 914 915 916 917 |
# File 'lib/google/apis/apphub_v1/service.rb', line 905 def create_project_location_application_workload(parent, workload_object = nil, request_id: nil, workload_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/workloads', ) command.request_representation = Google::Apis::ApphubV1::Workload::Representation command.request_object = workload_object command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['workloadId'] = workload_id unless workload_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_service_project_attachment(parent, service_project_attachment_object = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Attaches a service project to the host project.
1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1584 def (parent, = nil, request_id: nil, service_project_attachment_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/serviceProjectAttachments', ) command.request_representation = Google::Apis::ApphubV1::ServiceProjectAttachment::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['serviceProjectAttachmentId'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes an Application in a host project and location.
377 378 379 380 381 382 383 384 385 386 |
# File 'lib/google/apis/apphub_v1/service.rb', line 377 def delete_project_location_application(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes a Service from an Application.
724 725 726 727 728 729 730 731 732 733 |
# File 'lib/google/apis/apphub_v1/service.rb', line 724 def delete_project_location_application_service(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes a Workload from an Application.
952 953 954 955 956 957 958 959 960 961 |
# File 'lib/google/apis/apphub_v1/service.rb', line 952 def delete_project_location_application_workload(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1456 1457 1458 1459 1460 1461 1462 1463 1464 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1456 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Empty::Representation command.response_class = Google::Apis::ApphubV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_service_project_attachment(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Deletes a service project attachment.
1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1631 def (name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#detach_location_service_project_attachment(name, detach_service_project_attachment_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::DetachServiceProjectAttachmentResponse
Detaches a service project from a host project. You can call this API from any service project without needing access to the host project that it is attached to.
79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/apis/apphub_v1/service.rb', line 79 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:detachServiceProjectAttachment', ) command.request_representation = Google::Apis::ApphubV1::DetachServiceProjectAttachmentRequest::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1::DetachServiceProjectAttachmentResponse::Representation command.response_class = Google::Apis::ApphubV1::DetachServiceProjectAttachmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Location
Gets information about a location.
111 112 113 114 115 116 117 118 119 |
# File 'lib/google/apis/apphub_v1/service.rb', line 111 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Location::Representation command.response_class = Google::Apis::ApphubV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Application
Gets an Application in a host project and location.
409 410 411 412 413 414 415 416 417 |
# File 'lib/google/apis/apphub_v1/service.rb', line 409 def get_project_location_application(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Application::Representation command.response_class = Google::Apis::ApphubV1::Application command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
453 454 455 456 457 458 459 460 461 462 |
# File 'lib/google/apis/apphub_v1/service.rb', line 453 def get_project_location_application_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApphubV1::Policy::Representation command.response_class = Google::Apis::ApphubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Service
Gets a Service in an Application.
757 758 759 760 761 762 763 764 765 |
# File 'lib/google/apis/apphub_v1/service.rb', line 757 def get_project_location_application_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Service::Representation command.response_class = Google::Apis::ApphubV1::Service command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Workload
Gets a Workload in an Application.
985 986 987 988 989 990 991 992 993 |
# File 'lib/google/apis/apphub_v1/service.rb', line 985 def get_project_location_application_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Workload::Representation command.response_class = Google::Apis::ApphubV1::Workload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_boundary(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Boundary
Gets a Boundary.
142 143 144 145 146 147 148 149 150 |
# File 'lib/google/apis/apphub_v1/service.rb', line 142 def get_project_location_boundary(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Boundary::Representation command.response_class = Google::Apis::ApphubV1::Boundary command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::DiscoveredService
Gets a Discovered Service in a host project and location.
1118 1119 1120 1121 1122 1123 1124 1125 1126 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1118 def get_project_location_discovered_service(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::DiscoveredService::Representation command.response_class = Google::Apis::ApphubV1::DiscoveredService command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::DiscoveredWorkload
Gets a Discovered Workload in a host project and location.
1231 1232 1233 1234 1235 1236 1237 1238 1239 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1231 def get_project_location_discovered_workload(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::DiscoveredWorkload::Representation command.response_class = Google::Apis::ApphubV1::DiscoveredWorkload command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_extended_metadata_schema(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ExtendedMetadataSchema
Gets an Extended Metadata Schema.
1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1345 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::ExtendedMetadataSchema::Representation command.response_class = Google::Apis::ApphubV1::ExtendedMetadataSchema command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1487 1488 1489 1490 1491 1492 1493 1494 1495 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1487 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ServiceProjectAttachment
Gets a service project attachment.
1664 1665 1666 1667 1668 1669 1670 1671 1672 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1664 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ApphubV1::ServiceProjectAttachment::Representation command.response_class = Google::Apis::ApphubV1::ServiceProjectAttachment command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListServicesResponse
Lists Services in an Application.
798 799 800 801 802 803 804 805 806 807 808 809 810 |
# File 'lib/google/apis/apphub_v1/service.rb', line 798 def list_project_location_application_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/services', ) command.response_representation = Google::Apis::ApphubV1::ListServicesResponse::Representation command.response_class = Google::Apis::ApphubV1::ListServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListWorkloadsResponse
Lists Workloads in an Application.
1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1026 def list_project_location_application_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/workloads', ) command.response_representation = Google::Apis::ApphubV1::ListWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1::ListWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListApplicationsResponse
Lists Applications in a host project and location.
494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/google/apis/apphub_v1/service.rb', line 494 def list_project_location_applications(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/applications', ) command.response_representation = Google::Apis::ApphubV1::ListApplicationsResponse::Representation command.response_class = Google::Apis::ApphubV1::ListApplicationsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListDiscoveredServicesResponse
Lists Discovered Services that can be added to an Application in a host project and location.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1159 def list_project_location_discovered_services(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/discoveredServices', ) command.response_representation = Google::Apis::ApphubV1::ListDiscoveredServicesResponse::Representation command.response_class = Google::Apis::ApphubV1::ListDiscoveredServicesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListDiscoveredWorkloadsResponse
Lists Discovered Workloads that can be added to an Application in a host project and location.
1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1272 def list_project_location_discovered_workloads(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/discoveredWorkloads', ) command.response_representation = Google::Apis::ApphubV1::ListDiscoveredWorkloadsResponse::Representation command.response_class = Google::Apis::ApphubV1::ListDiscoveredWorkloadsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_extended_metadata_schemas(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListExtendedMetadataSchemasResponse
Lists Extended Metadata Schemas available in a host project and location.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1381 def (parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/extendedMetadataSchemas', ) command.response_representation = Google::Apis::ApphubV1::ListExtendedMetadataSchemasResponse::Representation command.response_class = Google::Apis::ApphubV1::ListExtendedMetadataSchemasResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1532 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::ApphubV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ApphubV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_service_project_attachments(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListServiceProjectAttachmentsResponse
Lists service projects attached to the host project.
1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1705 def (parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/serviceProjectAttachments', ) command.response_representation = Google::Apis::ApphubV1::ListServiceProjectAttachmentsResponse::Representation command.response_class = Google::Apis::ApphubV1::ListServiceProjectAttachmentsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/google/apis/apphub_v1/service.rb', line 194 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::ApphubV1::ListLocationsResponse::Representation command.response_class = Google::Apis::ApphubV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::LookupDiscoveredServiceResponse
Lists a Discovered Service in a host project and location, with a given resource URI.
1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1198 def lookup_project_location_discovered_service(parent, uri: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/discoveredServices:lookup', ) command.response_representation = Google::Apis::ApphubV1::LookupDiscoveredServiceResponse::Representation command.response_class = Google::Apis::ApphubV1::LookupDiscoveredServiceResponse command.params['parent'] = parent unless parent.nil? command.query['uri'] = uri unless uri.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::LookupDiscoveredWorkloadResponse
Lists a Discovered Workload in a host project and location, with a given resource URI.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1311 def lookup_project_location_discovered_workload(parent, uri: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/discoveredWorkloads:lookup', ) command.response_representation = Google::Apis::ApphubV1::LookupDiscoveredWorkloadResponse::Representation command.response_class = Google::Apis::ApphubV1::LookupDiscoveredWorkloadResponse command.params['parent'] = parent unless parent.nil? command.query['uri'] = uri unless uri.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#lookup_project_location_service_project_attachment(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::LookupServiceProjectAttachmentResponse
Lists a service project attachment for a given service project. You can call this API from any project to find if it is attached to a host project.
231 232 233 234 235 236 237 238 239 |
# File 'lib/google/apis/apphub_v1/service.rb', line 231 def (name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:lookupServiceProjectAttachment', ) command.response_representation = Google::Apis::ApphubV1::LookupServiceProjectAttachmentResponse::Representation command.response_class = Google::Apis::ApphubV1::LookupServiceProjectAttachmentResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates an Application in a host project and location.
549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/google/apis/apphub_v1/service.rb', line 549 def patch_project_location_application(name, application_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ApphubV1::Application::Representation command.request_object = application_object command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates a Service in an Application.
853 854 855 856 857 858 859 860 861 862 863 864 865 |
# File 'lib/google/apis/apphub_v1/service.rb', line 853 def patch_project_location_application_service(name, service_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ApphubV1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates a Workload in an Application.
1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 |
# File 'lib/google/apis/apphub_v1/service.rb', line 1082 def patch_project_location_application_workload(name, workload_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ApphubV1::Workload::Representation command.request_object = workload_object command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/google/apis/apphub_v1/service.rb', line 588 def set_application_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApphubV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ApphubV1::Policy::Representation command.response_class = Google::Apis::ApphubV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_application_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/google/apis/apphub_v1/service.rb', line 627 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApphubV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApphubV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApphubV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_boundary(name, boundary_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApphubV1::Operation
Updates a Boundary.
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/google/apis/apphub_v1/service.rb', line 280 def update_project_location_boundary(name, boundary_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::ApphubV1::Boundary::Representation command.request_object = boundary_object command.response_representation = Google::Apis::ApphubV1::Operation::Representation command.response_class = Google::Apis::ApphubV1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |