Class: Google::Apis::ApphubV1::ListApplicationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1::ListApplicationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/representations.rb,
lib/google/apis/apphub_v1/representations.rb
Overview
Response for ListApplications.
Instance Attribute Summary collapse
-
#applications ⇒ Array<Google::Apis::ApphubV1::Application>
List of Applications.
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListApplicationsResponse
constructor
A new instance of ListApplicationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListApplicationsResponse
Returns a new instance of ListApplicationsResponse.
712 713 714 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applications ⇒ Array<Google::Apis::ApphubV1::Application>
List of Applications.
Corresponds to the JSON property applications
700 701 702 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 700 def applications @applications end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
705 706 707 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 705 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
710 711 712 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 710 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
717 718 719 720 721 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 717 def update!(**args) @applications = args[:applications] if args.key?(:applications) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |