Class: Google::Apis::ApphubV1::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1::ListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/representations.rb,
lib/google/apis/apphub_v1/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::ApphubV1::Location>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
825 826 827 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::ApphubV1::Location>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
818 819 820 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 818 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
823 824 825 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 823 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
830 831 832 833 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 830 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |