Class: Google::Apis::ApphubV1::ListServiceProjectAttachmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1::ListServiceProjectAttachmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/representations.rb,
lib/google/apis/apphub_v1/representations.rb
Overview
Response for ListServiceProjectAttachments.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#service_project_attachments ⇒ Array<Google::Apis::ApphubV1::ServiceProjectAttachment>
List of service project attachments.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListServiceProjectAttachmentsResponse
constructor
A new instance of ListServiceProjectAttachmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListServiceProjectAttachmentsResponse
Returns a new instance of ListServiceProjectAttachmentsResponse.
889 890 891 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
877 878 879 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 877 def next_page_token @next_page_token end |
#service_project_attachments ⇒ Array<Google::Apis::ApphubV1::ServiceProjectAttachment>
List of service project attachments.
Corresponds to the JSON property serviceProjectAttachments
882 883 884 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 882 def @service_project_attachments end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
887 888 889 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 887 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
894 895 896 897 898 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 894 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @service_project_attachments = args[:service_project_attachments] if args.key?(:service_project_attachments) @unreachable = args[:unreachable] if args.key?(:unreachable) end |