Class: Google::Apis::ApphubV1::Service
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/representations.rb,
lib/google/apis/apphub_v1/representations.rb
Overview
Service is an App Hub data model that contains a discovered service, which represents a network or API interface that exposes some functionality to clients for consumption over the network.
Instance Attribute Summary collapse
-
#attributes ⇒ Google::Apis::ApphubV1::Attributes
Consumer provided attributes.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#discovered_service ⇒ String
Required.
-
#display_name ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#service_properties ⇒ Google::Apis::ApphubV1::ServiceProperties
Properties of an underlying cloud resource that can comprise a Service.
-
#service_reference ⇒ Google::Apis::ApphubV1::ServiceReference
Reference to an underlying networking resource that can comprise a Service.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
1421 1422 1423 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Google::Apis::ApphubV1::Attributes
Consumer provided attributes.
Corresponds to the JSON property attributes
1365 1366 1367 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1365 def attributes @attributes end |
#create_time ⇒ String
Output only. Create time.
Corresponds to the JSON property createTime
1370 1371 1372 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1370 def create_time @create_time end |
#description ⇒ String
Optional. User-defined description of a Service. Can have a maximum length of
2048 characters.
Corresponds to the JSON property description
1376 1377 1378 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1376 def description @description end |
#discovered_service ⇒ String
Required. Immutable. The resource name of the original discovered service.
Corresponds to the JSON property discoveredService
1381 1382 1383 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1381 def discovered_service @discovered_service end |
#display_name ⇒ String
Optional. User-defined name for the Service. Can have a maximum length of 63
characters.
Corresponds to the JSON property displayName
1387 1388 1389 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1387 def display_name @display_name end |
#name ⇒ String
Identifier. The resource name of a Service. Format: "projects/host-project-
id/locations/location/applications/application-id/services/service-id"
Corresponds to the JSON property name
1393 1394 1395 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1393 def name @name end |
#service_properties ⇒ Google::Apis::ApphubV1::ServiceProperties
Properties of an underlying cloud resource that can comprise a Service.
Corresponds to the JSON property serviceProperties
1398 1399 1400 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1398 def service_properties @service_properties end |
#service_reference ⇒ Google::Apis::ApphubV1::ServiceReference
Reference to an underlying networking resource that can comprise a Service.
Corresponds to the JSON property serviceReference
1403 1404 1405 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1403 def service_reference @service_reference end |
#state ⇒ String
Output only. Service state.
Corresponds to the JSON property state
1408 1409 1410 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1408 def state @state end |
#uid ⇒ String
Output only. A universally unique identifier (UUID) for the Service in the
UUID4 format.
Corresponds to the JSON property uid
1414 1415 1416 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1414 def uid @uid end |
#update_time ⇒ String
Output only. Update time.
Corresponds to the JSON property updateTime
1419 1420 1421 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1419 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1426 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @discovered_service = args[:discovered_service] if args.key?(:discovered_service) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @service_properties = args[:service_properties] if args.key?(:service_properties) @service_reference = args[:service_reference] if args.key?(:service_reference) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |