Class: Google::Apis::ApphubV1::ServiceProjectAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/representations.rb,
lib/google/apis/apphub_v1/representations.rb

Overview

ServiceProjectAttachment represents an attachment from a service project to a host project. Service projects contain the underlying cloud infrastructure resources, and expose these resources to the host project through a ServiceProjectAttachment. With the attachments, the host project can provide an aggregated view of resources across all service projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceProjectAttachment

Returns a new instance of ServiceProjectAttachment.



1479
1480
1481
# File 'lib/google/apis/apphub_v1/classes.rb', line 1479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time. Corresponds to the JSON property createTime

Returns:

  • (String)


1452
1453
1454
# File 'lib/google/apis/apphub_v1/classes.rb', line 1452

def create_time
  @create_time
end

#nameString

Identifier. The resource name of a ServiceProjectAttachment. Format: " projects/host-project-id/locations/global/serviceProjectAttachments/service- project-id." Corresponds to the JSON property name

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/apphub_v1/classes.rb', line 1459

def name
  @name
end

#service_projectString

Required. Immutable. Service project name in the format: "projects/abc" or " projects/123". As input, project name with either project id or number are accepted. As output, this field will contain project number. Corresponds to the JSON property serviceProject

Returns:

  • (String)


1466
1467
1468
# File 'lib/google/apis/apphub_v1/classes.rb', line 1466

def service_project
  @service_project
end

#stateString

Output only. ServiceProjectAttachment state. Corresponds to the JSON property state

Returns:

  • (String)


1471
1472
1473
# File 'lib/google/apis/apphub_v1/classes.rb', line 1471

def state
  @state
end

#uidString

Output only. A globally unique identifier (in UUID4 format) for the ServiceProjectAttachment. Corresponds to the JSON property uid

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/apphub_v1/classes.rb', line 1477

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1484
1485
1486
1487
1488
1489
1490
# File 'lib/google/apis/apphub_v1/classes.rb', line 1484

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @service_project = args[:service_project] if args.key?(:service_project)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
end