Class: Google::Apis::ApphubV1::ServiceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1::ServiceProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/representations.rb,
lib/google/apis/apphub_v1/representations.rb
Overview
Properties of an underlying cloud resource that can comprise a Service.
Instance Attribute Summary collapse
-
#extended_metadata ⇒ Hash<String,Google::Apis::ApphubV1::ExtendedMetadata>
Output only.
-
#functional_type ⇒ Google::Apis::ApphubV1::FunctionalType
The functional type of a service or workload.
-
#gcp_project ⇒ String
Output only.
-
#identity ⇒ Google::Apis::ApphubV1::Identity
The identity associated with a service or workload.
-
#location ⇒ String
Output only.
-
#registration_type ⇒ Google::Apis::ApphubV1::RegistrationType
The registration type of a service.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceProperties
constructor
A new instance of ServiceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceProperties
Returns a new instance of ServiceProperties.
1538 1539 1540 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extended_metadata ⇒ Hash<String,Google::Apis::ApphubV1::ExtendedMetadata>
Output only. Additional metadata specific to the resource type. The key is a
string that identifies the type of metadata and the value is the metadata
contents specific to that type. Key format: apphub.googleapis.com/
metadataType`
Corresponds to the JSON propertyextendedMetadata`
1503 1504 1505 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1503 def @extended_metadata end |
#functional_type ⇒ Google::Apis::ApphubV1::FunctionalType
The functional type of a service or workload.
Corresponds to the JSON property functionalType
1508 1509 1510 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1508 def functional_type @functional_type end |
#gcp_project ⇒ String
Output only. The service project identifier that the underlying cloud resource
resides in.
Corresponds to the JSON property gcpProject
1514 1515 1516 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1514 def gcp_project @gcp_project end |
#identity ⇒ Google::Apis::ApphubV1::Identity
The identity associated with a service or workload.
Corresponds to the JSON property identity
1519 1520 1521 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1519 def identity @identity end |
#location ⇒ String
Output only. The location that the underlying resource resides in, for example,
us-west1.
Corresponds to the JSON property location
1525 1526 1527 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1525 def location @location end |
#registration_type ⇒ Google::Apis::ApphubV1::RegistrationType
The registration type of a service.
Corresponds to the JSON property registrationType
1530 1531 1532 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1530 def registration_type @registration_type end |
#zone ⇒ String
Output only. The location that the underlying resource resides in if it is
zonal, for example, us-west1-a).
Corresponds to the JSON property zone
1536 1537 1538 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1536 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1543 1544 1545 1546 1547 1548 1549 1550 1551 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1543 def update!(**args) @extended_metadata = args[:extended_metadata] if args.key?(:extended_metadata) @functional_type = args[:functional_type] if args.key?(:functional_type) @gcp_project = args[:gcp_project] if args.key?(:gcp_project) @identity = args[:identity] if args.key?(:identity) @location = args[:location] if args.key?(:location) @registration_type = args[:registration_type] if args.key?(:registration_type) @zone = args[:zone] if args.key?(:zone) end |