Class: Google::Apis::ApphubV1::WorkloadProperties
- Inherits:
-
Object
- Object
- Google::Apis::ApphubV1::WorkloadProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apphub_v1/classes.rb,
lib/google/apis/apphub_v1/representations.rb,
lib/google/apis/apphub_v1/representations.rb
Overview
Properties of an underlying compute resource represented by the Workload.
Instance Attribute Summary collapse
-
#extended_metadata ⇒ Hash<String,Google::Apis::ApphubV1::ExtendedMetadata>
Output only.
-
#functional_type ⇒ Google::Apis::ApphubV1::FunctionalType
The functional type of a service or workload.
-
#gcp_project ⇒ String
Output only.
-
#identity ⇒ Google::Apis::ApphubV1::Identity
The identity associated with a service or workload.
-
#location ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadProperties
constructor
A new instance of WorkloadProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadProperties
Returns a new instance of WorkloadProperties.
1833 1834 1835 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extended_metadata ⇒ Hash<String,Google::Apis::ApphubV1::ExtendedMetadata>
Output only. Additional metadata specific to the resource type. The key is a
string that identifies the type of metadata and the value is the metadata
contents specific to that type. Key format: apphub.googleapis.com/
metadataType`
Corresponds to the JSON propertyextendedMetadata`
1803 1804 1805 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1803 def @extended_metadata end |
#functional_type ⇒ Google::Apis::ApphubV1::FunctionalType
The functional type of a service or workload.
Corresponds to the JSON property functionalType
1808 1809 1810 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1808 def functional_type @functional_type end |
#gcp_project ⇒ String
Output only. The service project identifier that the underlying cloud resource
resides in. Empty for non-cloud resources.
Corresponds to the JSON property gcpProject
1814 1815 1816 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1814 def gcp_project @gcp_project end |
#identity ⇒ Google::Apis::ApphubV1::Identity
The identity associated with a service or workload.
Corresponds to the JSON property identity
1819 1820 1821 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1819 def identity @identity end |
#location ⇒ String
Output only. The location that the underlying compute resource resides in (for
example, us-west1).
Corresponds to the JSON property location
1825 1826 1827 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1825 def location @location end |
#zone ⇒ String
Output only. The location that the underlying compute resource resides in if
it is zonal (for example, us-west1-a).
Corresponds to the JSON property zone
1831 1832 1833 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1831 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1838 1839 1840 1841 1842 1843 1844 1845 |
# File 'lib/google/apis/apphub_v1/classes.rb', line 1838 def update!(**args) @extended_metadata = args[:extended_metadata] if args.key?(:extended_metadata) @functional_type = args[:functional_type] if args.key?(:functional_type) @gcp_project = args[:gcp_project] if args.key?(:gcp_project) @identity = args[:identity] if args.key?(:identity) @location = args[:location] if args.key?(:location) @zone = args[:zone] if args.key?(:zone) end |